@@ -1,5 +1,5 @@
 /**
- * jQuery Messages UI 0.1.2
+ * jQuery Messages UI 0.1.3
  *
  * Copyright (c) 2011, Jonny Gerig Meyer
  * All rights reserved.
@@ -9,17 +9,20 @@
  */
 (function($) {
     $.fn.messages = function(opts) {
-        var options = $.extend({}, $.fn.messages.defaults, opts),
-        messageList = $(this),
+        var messageList = $(this),
+        options = $.extend({}, $.fn.messages.defaults, messageList.data('messages-ui-opts'), opts),
         messages = messageList.find(options.message),
-        transientMessages = messages.filter(options.transientMessage),
-        closeLink = messageList.find(options.closeLink).click(function() {
-            var thisMessage = $(this).closest(options.message);
-            thisMessage.fadeOut('fast', function() {
-                thisMessage.detach();
+        transientMessages = messages.filter(options.transientMessage);
+        messageList.data('messages-ui-opts', options);
+        if (options.closeLink) {
+            messageList.find(options.closeLink).click(function() {
+                var thisMessage = $(this).closest(options.message);
+                thisMessage.fadeOut('fast', function() {
+                    thisMessage.detach();
+                });
+                return false;
             });
-            return false;
-        });
+        }
         if (transientMessages.length) {
             $(document).bind('mousedown keydown', function(event) {
                 $.doTimeout(options.transientDelay, function() {
@@ -53,9 +56,9 @@
     $.fn.messages.defaults = {
         message: '.message',            // Selector for individual messages
         transientMessage: '.success',   // Selector for messages that will disappear on mousedown, keydown
-        closeLink: '.close',            // Selector for link that closes message
+        closeLink: '.close',            // Selector for link that closes message (set to ``false`` to disable close-link handlers)
         transientDelay: 500,            // Delay before mousedown or keydown events trigger transient message fade (ms)
-        transientFadeSpeed: 3000,        // Fade speed for transient messages (ms)
-        handleAjax: false          // Enable automatic handling of messages in "messages" key of JSON AJAX response
+        transientFadeSpeed: 3000,       // Fade speed for transient messages (ms)
+        handleAjax: false               // Enable automatic handling of messages in "messages" key of JSON AJAX response
     };
 })(jQuery);
